==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebCalendarBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DateRangeDescriptorDescriptionMetadata } from "./DateRangeDescriptorDescriptionMetadata";
import { WebCalendarBaseDescription } from "./WebCalendarBaseDescription";
/**
 * @hidden
 */
export let WebCalendarBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCalendarBaseDescriptionMetadata extends Base {
        static b(a) {
            if (WebCalendarBaseDescriptionMetadata.a == null) {
                WebCalendarBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCalendarBaseDescriptionMetadata.c(WebCalendarBaseDescriptionMetadata.a);
            }
            if (a.k(WebCalendarBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebCalendarBaseDescriptionMetadata.a);
            DateRangeDescriptorDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CalendarBase");
            a.item("__tagNameWC", "String:igc-calendar-base");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Selection", "ExportedType:string:CalendarBaseSelection");
            a.item("Selection@stringUnion", "WebComponents;React");
            a.item("Selection@names", "Single;Multiple;Range");
            a.item("ShowWeekNumbers", "Boolean");
            a.item("WeekStart", "ExportedType:string:CalendarBaseWeekStart");
            a.item("WeekStart@stringUnion", "WebComponents;React");
            a.item("WeekStart@names", "Sunday;Monday;Tuesday;Wednesday;Thursday;Friday;Saturday");
            a.item("Locale", "String");
            a.item("DisabledDates", "Array:DateRangeDescriptorDescription:IDateRangeDescriptor");
            a.item("SpecialDates", "Array:DateRangeDescriptorDescription:IDateRangeDescriptor");
        }
        static d(a) {
            WebCalendarBaseDescriptionMetadata.b(a);
            a.ad("WebCalendarBase", () => new WebCalendarBaseDescription());
            a.ac("WebCalendarBase", WebCalendarBaseDescriptionMetadata.a);
        }
    }
    WebCalendarBaseDescriptionMetadata.$t = markType(WebCalendarBaseDescriptionMetadata, 'WebCalendarBaseDescriptionMetadata');
    WebCalendarBaseDescriptionMetadata.a = null;
    return WebCalendarBaseDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebCalendarBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DateRangeDescriptorDescriptionMetadata } from "./DateRangeDescriptorDescriptionMetadata";
import { WebCalendarBaseDescription } from "./WebCalendarBaseDescription";
/**
 * @hidden
 */
export let WebCalendarBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCalendarBaseDescriptionMetadata extends Base {
        static b(a) {
            if (WebCalendarBaseDescriptionMetadata.a == null) {
                WebCalendarBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCalendarBaseDescriptionMetadata.c(WebCalendarBaseDescriptionMetadata.a);
            }
            if (a.k(WebCalendarBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCalendarBaseDescriptionMetadata.a);
            DateRangeDescriptorDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CalendarBase");
            a.item("__tagNameWC", "String:igc-calendar-base");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Selection", "ExportedType:string:CalendarSelection");
            a.item("Selection@stringUnion", "WebComponents;React");
            a.item("Selection@names", "Single;Multiple;Range");
            a.item("ShowWeekNumbers", "Boolean");
            a.item("WeekStart", "ExportedType:string:WeekDays");
            a.item("WeekStart@stringUnion", "WebComponents;React");
            a.item("WeekStart@names", "Sunday;Monday;Tuesday;Wednesday;Thursday;Friday;Saturday");
            a.item("Locale", "String");
            a.item("SpecialDates", "Array:DateRangeDescriptorDescription:IDateRangeDescriptor");
            a.item("DisabledDates", "Array:DateRangeDescriptorDescription:IDateRangeDescriptor");
        }
        static d(a) {
            WebCalendarBaseDescriptionMetadata.b(a);
            a.ae("WebCalendarBase", () => new WebCalendarBaseDescription());
            a.ad("WebCalendarBase", WebCalendarBaseDescriptionMetadata.a);
        }
    }
    WebCalendarBaseDescriptionMetadata.$t = markType(WebCalendarBaseDescriptionMetadata, 'WebCalendarBaseDescriptionMetadata');
    WebCalendarBaseDescriptionMetadata.a = null;
    return WebCalendarBaseDescriptionMetadata;
})();
